<?php
namespace Teknisa\CMP\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\CMP\Services\ReprocessarDadosService;

class ReprocessarDadosController {
    
    protected $service;

    public function __construct($service) {
        $this->service = $service;
    }
    
    //Executa as procedures para de acordo com o processo
    public function reprocessarDados(DTO\Request\Row $request, DTO\Response $response) {
        
        //Array das rows
        $rows = $request->getRow();
        
        //Verifica os processos e monta uma array com a quantidade de processos existente para cada processo
        $processos = $this->verificaProcesso($rows);
        
        try {
            if ($processos['processoUploadItens'] >= 1) {
                $procedureUploadItens = $this->service->procedureUploadItens();
            }
            if ($processos['processoUploadCadastroFornecedores'] >= 1) {
                $procedureUploadCadastroFornecedores = $this->service->procedureUploadCadastroFornecedores();
            }
            if ($processos['processoLocalEstoque'] >= 1) {
                $procedureLocalEstoque = $this->service->procedureLocalEstoque();
            }
            if ($processos['processoMovimentacao'] >= 1) {
                $procedureMovimentacao = $this->service->procedureMovimentacao();
            }
            if ($processos['processoMovimentacaoSKUAtualizacaoEstoque'] >= 1) {
                $procedureMovimentacaoSKUAtualizacaoEstoque = $this->service->procedureMovimentacaoSKUAtualizacaoEstoque();
            }
            if ($processos['processoOrigemSKU'] >= 1) {
                $procedureOrigemSKU = $this->service->procedureOrigemSKU();
            }
            if ($processos['processoLinhaPedidosColocados'] >= 1) {
                $procedureLinhaPedidosColocados = $this->service->procedureLinhaPedidosColocados();
            }
            if ($processos['processoCondicaoComercialSKU'] >= 1) {
                $procedureCondicaoComercialSKU = $this->service->procedureCondicaoComercialSKU();
            }
            if ($processos['processoPlanejamentoSemanal'] >= 1) {
                $procedurePlanejamentoSemanal = $this->service->procedurePlanejamentoSemanal();
            }
            if ($processos['processoLinhaPedidosLiberados'] >= 1) {
                $procedureLinhaPedidosLiberados = $this->service->procedureLinhaPedidosLiberados();
            }
            $response->addMessage(new Message('success'));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    } 
    
    //Verifica os processos e monta uma array de processos com suas devidas quantidades
    public function verificaProcesso($rows) {
        
        //Array de processos
        $processos = array(
            'processoUploadItens' => 0,
            'processoUploadCadastroFornecedores' => 0,
            'processoLocalEstoque' => 0,
            'processoMovimentacao' => 0, 
            'processoMovimentacaoSKUAtualizacaoEstoque' => 0,
            'processoOrigemSKU' => 0,
            'processoLinhaPedidosColocados' => 0,
            'processoCondicaoComercialSKU' => 0,
            'processoPlanejamentoSemanal' => 0,
            'processoLinhaPedidosLiberados' => 0
        );
        
        //Passa por cada row, verifica qul é o processo e armazena em sua devida posição na array de processos
        forEach($rows as $row) {
            if ($row['IDPROCESSO'] === "USR_PRODFORNCOMP_NGD") {
                $processos['processoUploadItens']++;
            }
            if ($row['IDPROCESSO'] === "USR_FORNECEDOR_NGD") {
                $processos['processoUploadCadastroFornecedores']++;
            }
            if ($row['IDPROCESSO'] === "USR_FILIOPELOG_NGD") {
                $processos['processoLocalEstoque']++;
            }
            if ($row['IDPROCESSO'] === "USR_ITEMPRODUTO_NGD") {
                $processos['processoMovimentacao']++;
            }
            if ($row['IDPROCESSO'] === "USR_ITLANCTOEST_NGD") {
                $processos['processoMovimentacaoSKUAtualizacaoEstoque']++;
            }
            if ($row['IDPROCESSO'] === "USR_REFORFIL_NGD") {
                $processos['processoOrigemSKU']++;
            }
            if ($row['IDPROCESSO'] === "USR_ITEMAUTFOL_NGD") {
                $processos['processoLinhaPedidosColocados']++;
            }
            if ($row['IDPROCESSO'] === "USR_ITEMCOLE_NGD") {
                $processos['processoCondicaoComercialSKU']++;
            }
            if ($row['IDPROCESSO'] === "USR_ITMEAUTFDEST_NGD") {
                $processos['processoPlanejamentoSemanal']++;
            }
            if ($row['IDPROCESSO'] === "USR_AUTOFORNE_NGD") {
                $processos['processoLinhaPedidosLiberados']++;
            }
        };
        return $processos;
    }

}